@@ -180,6 +180,7 @@ impl LuaState {
 			self.get_global(crate::lua_string!("ErrorNoHaltWithStack"));
 			if self.is_nil(-1) {
 				eprintln!("[ERROR] {:?}", self.get_string(-2));
+				self.pop_n(2);
 				return false;
 			}
 			self.push_value(-2);
@@ -238,7 +239,12 @@ impl LuaState {
 	}
 
 	pub unsafe fn lua_type_name(&self, lua_type_id: i32) -> Cow<'_, str> {
+		let hackfix = self.get_top(); // https://github.com/Facepunch/garrysmod-issues/issues/5134
+
 		let type_str_ptr = (LUA_SHARED.lua_typename)(*self, lua_type_id);
+
+		self.pop_n((self.get_top() - hackfix).max(0));
+
 		let type_str = std::ffi::CStr::from_ptr(type_str_ptr);
 		type_str.to_string_lossy()
 	}
@@ -473,7 +479,7 @@ impl LuaState {
 		if has_metatable {
 			self.push_value(-2);
 			self.set_metatable(-2);
-			self.remove(-2);
+			self.remove(self.get_top() - 1);
 		}
 
 		ptr.write(data);
@@ -566,13 +572,13 @@ impl LuaState {
 			},
 			"boolean" => {
 				self.push_value(index);
-				let boolean = self.get_boolean(index);
+				let boolean = self.get_boolean(-1);
 				self.pop();
 				format!("{}", boolean)
 			},
 			"number" => {
 				self.push_value(index);
-				let n = self.to_number(index);
+				let n = self.to_number(-1);
 				self.pop();
 				format!("{}", n)
 			},
